/*
    Copyright (C) 2003 <ryu@gpul.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include <osgCal/Model>

#include <osgDB/Registry>
#include <osgDB/Input>
#include <osgDB/Output>

using namespace osg;
using namespace osgDB;
using namespace osgCal;

// forward declare functions to use later.
bool Model_readLocalData(Object& obj, Input& fr);
bool Model_writeLocalData(const Object& obj, Output& fw);

bool Model_matchModeStr(const char* str,int& mode);
const char* Model_getModeStr(int value);

RegisterDotOsgWrapperProxy g_ModelProxy
(
    new osgCal::Model,
    "Model",
    "Object Node Model",
    &Model_readLocalData,
    &Model_writeLocalData
);

bool Model_readLocalData(Object& obj, Input& fr)
{
    bool iteratorAdvanced = false;

    Model& model = static_cast<Model&>(obj);

    osg::ref_ptr<osgCal::CoreModel> proto = new osgCal::CoreModel();

    osgCal::CoreModel *core = static_cast<osgCal::CoreModel *>(fr.readObjectOfType(*proto));

    if (core) {
	core->loadAllTextures();
	model.create(core);
        iteratorAdvanced = true;
    }

    if (fr.matchSequence("starting")) {
        if (fr[1].isInt()) {
            int animation;
            fr[1].getInt(animation);
            model.loop(animation, 1.0f, 0.0f);
            iteratorAdvanced = true;
            fr += 2;
        }
    }

    return iteratorAdvanced;
}

bool Model_writeLocalData(const Object& obj, Output& fw)
{
    const Model& model = static_cast<const Model&>(obj);
    std::vector<std::string> items;

    fw.writeObject(*model.getCoreModel());

#if 1
    extern bool Geode_writeLocalData(const osg::Object& obj, Output& fw);

    Geode_writeLocalData(obj,fw);
#endif    

    return true;
}
